# frozen_string_literal: true

# Copyright from 2019 Paulo Arruda (parrudaj at gmail dot com)
#
# Licensed under the Commons Clause + Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'gotta/queue/memory/version'
require 'gotta/queue'

module Gotta
  module Queue
    module Memory
      class Error < StandardError; end

      class Driver
        attr_reader :name

        def initialize(name)
          @name = name
          @queue = ::Queue.new
        end

        def pop
          @queue.pop
        end

        def push(value)
          @queue.push(value)
        end

        def process
          loop do
            yield pop
          end
        end
      end
    end
  end
end
